summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSebastian Huber <sebastian.huber@embedded-brains.de>2020-09-18 10:36:27 +0200
committerSebastian Huber <sebastian.huber@embedded-brains.de>2020-09-22 10:06:05 +0200
commit073db3e5e7996d1aa75079430aad751d254c7b78 (patch)
tree5e4a0fc9fcafb51dcce3a6ba1361c27ceb5d4420
parentbb30c484437496a7ea59455cabd3edd2a3233a55 (diff)
tc attr
-rw-r--r--testsuites/validation/tc-attr.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/testsuites/validation/tc-attr.c b/testsuites/validation/tc-attr.c
index 9194c3c286..1c840d8b47 100644
--- a/testsuites/validation/tc-attr.c
+++ b/testsuites/validation/tc-attr.c
@@ -59,7 +59,7 @@
*
* - Validate the non-default attribute constants.
*
* - Check that RTEMS_BARRIER_MANUAL_RELEASE is a power of two.
*
* - Check that RTEMS_BINARY_SEMAPHORE is a power of two.
*
@@ -146,7 +146,7 @@ T_TEST_CASE( RtemsAttrValAttr )
T_plan(22);
/* No action */
- T_step_true( 0, IsPowerOfTwo( RTEMS_BARRIER_MANUAL_RELEASE ) );
+ T_step_true( 0, IsPowerOfTwo( RTEMS_BARRIER_AUTOMATIC_RELEASE ) );
T_step_true( 1, IsPowerOfTwo( RTEMS_BINARY_SEMAPHORE ) );
T_step_true( 2, IsPowerOfTwo( RTEMS_FLOATING_POINT ) );
T_step_true( 3, IsPowerOfTwo( RTEMS_GLOBAL ) );
@@ -59,7 +59,7 @@
* - Validate the non-default attribute constants.
*
- * - Check that RTEMS_BARRIER_MANUAL_RELEASE is a power of two.
+ * - Check that RTEMS_BARRIER_AUTOMATIC_RELEASE is a power of two.
*
* - Check that RTEMS_BINARY_SEMAPHORE is a power of two.